@@ -40,7 +40,7 @@ int32_t SPVM__MIME__QuotedPrint__encode_qp(SPVM_ENV* env, SPVM_VALUE* stack) {
         void* obj_str = stack[0].oval;
         
         if (!obj_str) {
-                return env->die(env, stack, "$string must be defined", __func__, FILE_NAME, __LINE__);
+                return env->die_v2(env, stack, "$string must be defined", __func__, FILE_NAME, __LINE__);
         }
         
         beg = (char*)env->get_chars(env, stack, obj_str);
@@ -148,7 +148,7 @@ int32_t SPVM__MIME__QuotedPrint__decode_qp(SPVM_ENV* env, SPVM_VALUE* stack) {
         void* obj_str = stack[0].oval;
         
         if (!obj_str) {
-                return env->die(env, stack, "$string must be defined", __func__, FILE_NAME, __LINE__);
+                return env->die_v2(env, stack, "$string must be defined", __func__, FILE_NAME, __LINE__);
         }
         
         int32_t len = env->length(env, stack, obj_str);
